@@ -2,7 +2,7 @@
  * vinagre-window.c
  * This file is part of vinagre
  *
- * Copyright (C) 2007 - Jonh Wendell <wendell@bani.com.br>
+ * Copyright (C) 2007,2008 - Jonh Wendell <wendell@bani.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,11 +73,18 @@ vinagre_window_delete_event (GtkWidget   *widget,
 			     GdkEventAny *event)
 {
   VinagreWindow *window = VINAGRE_WINDOW (widget);
+  GtkClipboard  *cb;
+
+  cb = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 
   if (window->priv->signal_notebook > 0)
     g_signal_handler_disconnect (window->priv->notebook,
 				 window->priv->signal_notebook);
 
+  if (window->priv->signal_clipboard > 0)
+    g_signal_handler_disconnect (cb,
+				 window->priv->signal_clipboard);
+
   vinagre_window_close_all_tabs (window);
   gtk_main_quit ();
 
@@ -261,11 +268,26 @@ static void
 activate_recent_cb (GtkRecentChooser *action, VinagreWindow *window)
 {
   VinagreConnection *conn;
+  gchar             *error, *msg;
 
-  conn = vinagre_connection_new_from_string (gtk_recent_chooser_get_current_uri (action));
-  vinagre_cmd_open_bookmark (window, conn);
+  conn = vinagre_connection_new_from_string (gtk_recent_chooser_get_current_uri (action),
+					     &error);
+  if (conn)
+    {
+      vinagre_cmd_open_bookmark (window, conn);
+      vinagre_connection_free (conn);
+    }
+  else
+    {
+      msg = g_strdup_printf ("%s %s",
+			     _("The following error has occurred:"),
+			     error ? error : _("Unknown error"));
+      vinagre_utils_show_error (msg, GTK_WINDOW (window));
+      g_free (msg);
+    }
 
-  vinagre_connection_free (conn);
+  if (error)
+    g_free (error);
 }
 
 static void update_recent_connections (VinagreWindow *window)
@@ -299,11 +321,12 @@ static void
 create_menu_bar_and_toolbar (VinagreWindow *window, 
 			     GtkWidget     *main_box)
 {
-  GtkActionGroup *action_group;
-  GtkUIManager *manager;
-  GError *error = NULL;
+  GtkActionGroup   *action_group;
+  GtkUIManager     *manager;
+  GError           *error = NULL;
   GtkRecentManager *recent_manager;
-  GtkRecentFilter *filter;
+  GtkRecentFilter  *filter;
+  GtkAction        *action;
 
   manager = gtk_ui_manager_new ();
   window->priv->manager = manager;
@@ -337,6 +360,9 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
   g_object_unref (action_group);
   window->priv->always_sensitive_action_group = action_group;
 
+  action = gtk_action_group_get_action (action_group, "MachineConnect");
+  g_object_set (action, "is_important", TRUE, NULL);
+
   action_group = gtk_action_group_new ("VinagreWindowActions");
   gtk_action_group_set_translation_domain (action_group, NULL);
   gtk_action_group_add_actions (action_group,
@@ -348,6 +374,9 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
   g_object_unref (action_group);
   window->priv->action_group = action_group;
 
+  action = gtk_action_group_get_action (action_group, "MachineClose");
+  g_object_set (action, "is_important", TRUE, NULL);
+
   /* Machine connected actions */
   action_group = gtk_action_group_new ("VinagreWindowMachineConnectedActions");
   gtk_action_group_set_translation_domain (action_group, NULL);
@@ -360,6 +389,11 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
   g_object_unref (action_group);
   window->priv->machine_connected_action_group = action_group;
 
+  action = gtk_action_group_get_action (action_group, "ViewFullScreen");
+  g_object_set (action, "is_important", TRUE, NULL);
+  action = gtk_action_group_get_action (action_group, "MachineTakeScreenshot");
+  g_object_set (action, "is_important", TRUE, NULL);
+
   /* now load the UI definition */
   gtk_ui_manager_add_ui_from_file (manager, vinagre_utils_get_ui_xml_filename (), &error);
   if (error != NULL)
@@ -394,6 +428,14 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
   window->priv->recent_action = gtk_recent_action_new ("recent_connections",
 						     _("_Recent connections"),
 						       NULL, NULL);
+  g_object_set (G_OBJECT (window->priv->recent_action),
+		"show-not-found", TRUE,
+		"local-only", FALSE,
+		"show-private", TRUE,
+		"show-tips", TRUE,
+		"sort-type", GTK_RECENT_SORT_MRU,
+		NULL);
+  gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (window->priv->recent_action), FALSE);
   g_signal_connect (window->priv->recent_action,
 		    "item-activated",
 		    G_CALLBACK (activate_recent_cb),
@@ -620,11 +662,6 @@ init_widgets_visibility (VinagreWindow *window)
 					"BookmarksEdit");
   gtk_action_set_sensitive (action, FALSE);
 
-  /* TODO: Implement these commands */
-  action = gtk_action_group_get_action (window->priv->always_sensitive_action_group,
-					"HelpContents");
-  gtk_action_set_sensitive (action, FALSE);
-
   /* fav panel visibility */
   action = gtk_action_group_get_action (window->priv->always_sensitive_action_group,
 					"ViewBookmarks");
@@ -829,7 +866,10 @@ vinagre_window_init_clipboard (VinagreWindow *window)
   GtkClipboard *cb;
 
   cb = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-  g_signal_connect (cb, "owner-change", G_CALLBACK (vinagre_window_clipboard_cb), window);
+  window->priv->signal_clipboard = g_signal_connect (cb,
+						     "owner-change",
+						     G_CALLBACK (vinagre_window_clipboard_cb),
+						     window);
 }
 
 static void
